<?php

namespace qyrr;


class QYRR_Bulk_Download {

	/**
	 * Contains instance or null
	 *
	 * @var object|null
	 */
	private static $instance = null;

	/**
	 * Returns instance of QYRR_Bulk_Download.
	 *
	 * @return object
	 */
	public static function get_instance() {

		if ( null === self::$instance ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * Constructor for QYRR_Bulk_Download.
	 */
	public function __construct() {
		add_filter( 'bulk_actions-edit-qr', array( $this, 'add_bulk_download_action' ) );
		add_filter( 'handle_bulk_actions-edit-qr', array( $this, 'handle_download_action' ), 10, 3 );
		add_action( 'admin_notices', array( $this, 'add_notice' ) );
	}

	public function add_bulk_download_action( $bulk_actions ) {
		$bulk_actions['download'] = __( 'Download QR-Codes', 'qyrr-code' );

		return $bulk_actions;
	}

	public function handle_download_action( $redirect_url, $action, $post_ids ) {
		if ( $action == 'download' ) {
			global $wp_filesystem;

			if ( ! function_exists( 'WP_Filesystem' ) ) {
				require_once( ABSPATH . 'wp-admin/includes/file.php' );
			}

			if ( is_null( $wp_filesystem ) ) {
				WP_Filesystem();
			}

			// Create new temporary directory.
			$uploads_dir = wp_upload_dir();
			$temp_dir    = $uploads_dir['basedir'] . DIRECTORY_SEPARATOR . 'qyrr' . DIRECTORY_SEPARATOR . 'download';

			// Reset temp directory.
			if ( file_exists( $temp_dir ) ) {
				$wp_filesystem->delete( $temp_dir, true );
				wp_mkdir_p( $temp_dir );
			}

			foreach ( $post_ids as $post_id ) {
				// Create directory for post id.
				$file_dir      = $uploads_dir['basedir'] . DIRECTORY_SEPARATOR . 'qyrr' . DIRECTORY_SEPARATOR . $post_id;
				$file_temp_dir = $temp_dir . DIRECTORY_SEPARATOR . $post_id;
				$file_name     = apply_filters( 'qyrr_file_name', 'qr-code', $post_id );

				if ( ! file_exists( $file_temp_dir ) ) {
					wp_mkdir_p( $file_temp_dir );
				}

				// Copy file.
				copy( $file_dir . DIRECTORY_SEPARATOR . $file_name . '.png', $file_temp_dir . DIRECTORY_SEPARATOR . $file_name . '.png' );
			}

			// Create ZIP file.
			$zip_url = Qyrr_ZIP::create_zip_file( $temp_dir );

			// Setup message parameters.
			$redirect_url = add_query_arg( array(
				'download' => count( $post_ids ),
				'zip'      => $zip_url,
			), $redirect_url );

		}

		return $redirect_url;
	}

	public function add_notice() {
		if ( ! empty( $_REQUEST['download'] ) && ! empty( $_REQUEST['zip'] ) ) {
			printf( '<div id="message" class="updated notice is-dismissable"><p>' . esc_html__( 'Download the ZIP file %s (Contains %d QR-Codes)', 'qyrr-code' ) . '</p></div>', '<a href="' . esc_url( $_REQUEST['zip'] ) . '">' . esc_html__( 'here', 'qyrr-code' ) . '</a>', intval( $_REQUEST['download'] ) );
		}
	}
}