<?php

namespace qyrr;


class QYRR_Dynamic_Code {

	/**
	 * Contains instance or null
	 *
	 * @var object|null
	 */
	private static $instance = null;

	/**
	 * Returns instance of QYRR_Dynamic_Code.
	 *
	 * @return object
	 */
	public static function get_instance() {

		if ( null === self::$instance ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * Constructor for QYRR_Dynamic_Code.
	 */
	public function __construct() {
		add_action( 'init', array( $this, 'handle_dynamic_link' ) );
	}

	/**
	 * Track and redirect to QR code source.
	 * @return void
	 */
	public function handle_dynamic_link() {
		// Check if the webhook should be fired.
		if ( ! isset( $_GET['qyrr'] ) ) {
			return;
		}

		// Check if it's an URL type.
		$qr_id     = esc_attr( $_GET['qyrr'] );
		$source    = esc_html( get_post_meta( $qr_id, 'source', true ) );
		$post_link = esc_url( get_post_meta( $qr_id, 'post-link', true ) );
		$url       = esc_url( get_post_meta( $qr_id, 'url', true ) );

		if ( $source !== 'post' && $source !== 'url' ) {
			return;
		}

		// Get the link to redirect to.
		if ( ! empty( $post_link ) && $source === 'post' ) {
			// Track and redirect to post link.
			$clicks = intval( get_post_meta( $qr_id, 'clicks', true ) );
			update_post_meta( $qr_id, 'clicks', $clicks + 1);

			wp_redirect( $post_link );
			exit;
		}

		if ( ! empty( $url ) && $source === 'url' ) {
			// Track and redirect to URL.
			$clicks = intval( get_post_meta( $qr_id, 'clicks', true ) );
			update_post_meta( $qr_id, 'clicks', $clicks + 1);

			wp_redirect( $url );
			exit;
		}
	}
}