<?php

namespace qyrr;


class QYRR_Generator {

	public static function generate_qr_by_source( $post_id, $data, $iterator, $campaign ) {

		// Get the source data.
		$source          = get_post_meta( $post_id, 'source', true );
		$is_dynamic_old  = get_post_meta( $post_id, 'dynamic-code', true );
		$is_dynamic_post = get_post_meta( $post_id, 'dynamic-post', true );
		$is_dynamic_url  = get_post_meta( $post_id, 'dynamic-url', true );

		$is_dynamic = false;

		if ( $is_dynamic_post || $is_dynamic_url || $is_dynamic_old ) {
			$is_dynamic = true;
		}

		$source_meta = array();

		// Create qr code.
		$qr_code_data = array(
			'post_title'   => get_the_title( $post_id ) . ' ' . $iterator,
			'post_content' => '<!-- wp:qyrr-code/qr /-->',
			'post_status'  => 'publish',
			'post_type'    => 'qr'
		);

		// Insert the post into the database
		$new_post_id = wp_insert_post( $qr_code_data );

		// Maybe assign a campaign.
		if ( $campaign ) {
			wp_set_object_terms( $new_post_id, array( intval( $campaign ) ), 'campaign' );
		}

		switch ( $source ) {
			case 'post':
				$source_meta = array(
					'post-type' => get_post_meta( $post_id, 'post-type', true ),
					'post-link' => $data,
					'source'    => 'post'
				);
				break;
			case 'url':
				$source_meta = array(
					'url'    => $data,
					'source' => 'url'
				);
				break;
			case 'text':
				$source_meta = array(
					'text'   => $data,
					'source' => 'text'
				);
				break;
			case 'email':
				$source_meta = array(
					'e-mail' => $data,
					'source' => 'email'
				);
				break;
			case 'phone':
				$source_meta = array(
					'phone-number' => $data,
					'source'       => 'phone'
				);
				break;
			case 'sms':
				$source_meta = array(
					'sms-text' => $data,
					'source'   => 'sms'
				);
				break;
			case 'whatsapp':
				$source_meta = array(
					'whatsapp-text' => $data,
					'source'        => 'whatsapp'
				);
				break;
			case 'location':
				$source_meta = array(
					'latitude'  => get_post_meta( $post_id, 'latitude', true ),
					'longitude' => get_post_meta( $post_id, 'longitude', true ),
					'source'    => 'location'
				);
				break;
			case 'wifi':
				$source_meta = array(
					'wifi-type' => get_post_meta( $post_id, 'wifi-type', true ),
					'ssid'      => get_post_meta( $post_id, 'ssid', true ),
					'password'  => get_post_meta( $post_id, 'password', true ),
					'source'    => 'wifi'
				);
				break;
			case 'vcard':
				$source_meta = array(
					'vcard-first-name' => get_post_meta( $post_id, 'vcard-first-name', true ),
					'vcard-last-name'  => get_post_meta( $post_id, 'vcard-last-name', true ),
					'vcard-company'    => get_post_meta( $post_id, 'vcard-company', true ),
					'vcard-address'    => get_post_meta( $post_id, 'vcard-address', true ),
					'vcard-phone'      => get_post_meta( $post_id, 'vcard-phone', true ),
					'vcard-url'        => get_post_meta( $post_id, 'vcard-url', true ),
					'vcard-email'      => get_post_meta( $post_id, 'vcard-email', true ),
					'source'           => 'vcard'
				);
				break;
		}


		// Get meta from existing QR-Code.
		$meta_fields = array(
			'dynamic-post'         => get_post_meta( $post_id, 'dynamic-post', true ),
			'dynamic-url'          => get_post_meta( $post_id, 'dynamic-url', true ),
			'qr-content'           => $data,
			'render-mode'          => get_post_meta( $post_id, 'render-mode', true ),
			'size'                 => get_post_meta( $post_id, 'size', true ),
			'fill-color'           => get_post_meta( $post_id, 'fill-color', true ),
			'background-color'     => get_post_meta( $post_id, 'background-color', true ),
			'min-version'          => get_post_meta( $post_id, 'min-version', true ),
			'error-handling-level' => get_post_meta( $post_id, 'error-handling-level', true ),
			'template'             => get_post_meta( $post_id, 'template', true ),
			'quiet-zone'           => get_post_meta( $post_id, 'quiet-zone', true ),
			'corner-radius'        => get_post_meta( $post_id, 'corner-radius', true ),
			'logo-size'            => get_post_meta( $post_id, 'logo-size', true ),
			'position-x'           => get_post_meta( $post_id, 'position-x', true ),
			'position-y'           => get_post_meta( $post_id, 'position-y', true ),
			'label-text'           => get_post_meta( $post_id, 'label-text', true ),
			'font'                 => get_post_meta( $post_id, 'font', true ),
			'font-color'           => get_post_meta( $post_id, 'font-color', true ),
			'logo-upload'          => get_post_meta( $post_id, 'logo-upload', true ),
			'download_format'      => get_post_meta( $post_id, 'download_format', true ),
			'qr-image-url'         => get_post_meta( $post_id, 'qr-image-url', true ),
			'clicks'               => 0,
		);

		if ( $is_dynamic ) {
			$meta_fields['qr-content'] = get_bloginfo( 'url' ) . '?qyrr=' . $new_post_id . '&quid=' . $iterator;
		}

		$meta_fields = array_merge( $source_meta, $meta_fields );

		// Now we can update meta.
		foreach ( $meta_fields as $key => $value ) {
			update_post_meta( $new_post_id, $key, $value );
		}

		return $new_post_id;

	}

	public static function generate_qr_by_number( $post_id, $iterator, $campaign ) {

		// Get the source data.
		$source          = get_post_meta( $post_id, 'source', true );
		$is_dynamic_old  = get_post_meta( $post_id, 'dynamic-code', true );
		$is_dynamic_post = get_post_meta( $post_id, 'dynamic-post', true );
		$is_dynamic_url  = get_post_meta( $post_id, 'dynamic-url', true );

		$is_dynamic = false;

		if ( $is_dynamic_post || $is_dynamic_url || $is_dynamic_old ) {
			$is_dynamic = true;
		}

		$source_meta = array();

		// Create qr code.
		$qr_code_data = array(
			'post_title'   => get_the_title( $post_id ) . ' ' . $iterator,
			'post_content' => '<!-- wp:qyrr-code/qr /-->',
			'post_status'  => 'publish',
			'post_type'    => 'qr'
		);

		// Insert the post into the database
		$new_post_id = wp_insert_post( $qr_code_data );

		// Maybe assign a campaign.
		if ( $campaign ) {
			wp_set_object_terms( $new_post_id, array( intval( $campaign ) ), 'campaign' );
		}

		switch ( $source ) {
			case 'post':
				$source_meta = array(
					'post-type' => get_post_meta( $post_id, 'post-type', true ),
					'post-link' => get_post_meta( $post_id, 'post-link', true ),
					'source'    => 'post'
				);

				if ( $is_dynamic ) {
					$source_meta['qr-content'] = get_bloginfo( 'url' ) . '?qyrr=' . $new_post_id . '&quid=' . $iterator;
				} else {
					$source_meta['qr-content'] = get_post_meta( $post_id, 'qr-content', true ) . '&quid=' . $iterator;
				}

				break;
			case 'url':
				$source_meta = array(
					'url'    => get_post_meta( $post_id, 'url', true ),
					'source' => 'url'
				);

				if ( $is_dynamic ) {
					$source_meta['qr-content'] = get_bloginfo( 'url' ) . '?qyrr=' . $new_post_id . '&quid=' . $iterator;
				} else {
					$source_meta['qr-content'] = get_post_meta( $post_id, 'qr-content', true ) . '&quid=' . $iterator;
				}

				break;
		}


		// Get meta from existing QR-Code.
		$meta_fields = array(
			'dynamic-post'         => get_post_meta( $post_id, 'dynamic-post', true ),
			'dynamic-url'          => get_post_meta( $post_id, 'dynamic-url', true ),
			'render-mode'          => get_post_meta( $post_id, 'render-mode', true ),
			'size'                 => get_post_meta( $post_id, 'size', true ),
			'fill-color'           => get_post_meta( $post_id, 'fill-color', true ),
			'background-color'     => get_post_meta( $post_id, 'background-color', true ),
			'min-version'          => get_post_meta( $post_id, 'min-version', true ),
			'error-handling-level' => get_post_meta( $post_id, 'error-handling-level', true ),
			'quiet-zone'           => get_post_meta( $post_id, 'quiet-zone', true ),
			'corner-radius'        => get_post_meta( $post_id, 'corner-radius', true ),
			'logo-size'            => get_post_meta( $post_id, 'logo-size', true ),
			'position-x'           => get_post_meta( $post_id, 'position-x', true ),
			'position-y'           => get_post_meta( $post_id, 'position-y', true ),
			'label-text'           => get_post_meta( $post_id, 'label-text', true ),
			'font'                 => get_post_meta( $post_id, 'font', true ),
			'font-color'           => get_post_meta( $post_id, 'font-color', true ),
			'logo-upload'          => get_post_meta( $post_id, 'logo-upload', true ),
			'download_format'      => get_post_meta( $post_id, 'download_format', true ),
			'qr-image-url'         => get_post_meta( $post_id, 'qr-image-url', true ),
			'clicks'               => 0,
		);

		$meta_fields = array_merge( $source_meta, $meta_fields );

		// Now we can update meta.
		foreach ( $meta_fields as $key => $value ) {
			update_post_meta( $new_post_id, $key, $value );
		}

		return $new_post_id;
	}
}