<?php

namespace qyrr;

if ( class_exists( 'ZipArchive' ) ) {
	/**
	 * Class which handles ZIP file creation.
	 */
	class Qyrr_ZIP extends \ZipArchive {

		/**
		 * Add directory to zip file
		 *
		 * @param string $location given path.
		 * @param string $name given filename.
		 *
		 * @return void
		 */
		private function add_dir( $location, $name ) {
			$this->addEmptyDir( $name );
			$this->add_files( $location, $name );
		}

		/**
		 * Create zip file while add directory.
		 *
		 * @param string $location full path.
		 * @param string $name file name.
		 *
		 * @return void
		 */
		private function add_files( $location, $name ) {
			$name     .= DIRECTORY_SEPARATOR;
			$location .= DIRECTORY_SEPARATOR;
			$dir      = opendir( $location );

			while ( $file = readdir( $dir ) ) {
				if ( '.' == $file || '..' == $file ) {
					continue;
				}
				if ( filetype( $location . $file ) == 'dir' ) {
					$do = 'add_dir';
				} else {
					$do = 'addFile';
				}
				$this->$do( $location . $file, $name . $file );
			}
		}

		/**
		 * @param $directory current directory to ZIP.
		 *
		 * @return false|void
		 */
		public static function create_zip_file( $directory ) {
			$uploads_dir = wp_upload_dir();

			$zip_name = 'qyrr-download-' . time() . '.zip';
			$zip_path = $uploads_dir['basedir'] . DIRECTORY_SEPARATOR . 'qyrr' . DIRECTORY_SEPARATOR  . 'download' . DIRECTORY_SEPARATOR. $zip_name;
			$zip_url  = $uploads_dir['baseurl'] . '/qyrr/download/' . $zip_name;

			// adding it to a zip file.
			$archive = new self();
			$result  = $archive->open( $zip_path, \ZipArchive::CREATE );

			if ( true === $result ) {
				$archive->add_dir( $directory, basename( $directory ) );
				$archive->close();
			} else {
				return false;
			}

			return $zip_url;
		}
	}
}
